# Theory

Equations and models implemented in `flow_state`. Theory is provided for each component below.

## Contents

- [Gas Properties](gas-properties.md): R, γ, cp, cv, equation of state
- [Gas Models](gas-models.md): Perfect gas, Park, Equilibrium air
- [Definitions](definitions.md): Speed of sound, Mach number, Reynolds number
- [Isentropic Relations](isentropic.md): Stagnation-to-static ratios
- [Transport Models](transport.md): Viscosity laws (Sutherland, Keyes, etc.)
- [Atmosphere Models](atmosphere-models.md): USSA76 and CIRA86


